PacketType

Enum PacketType 

pub enum PacketType {
    Event,
    Lap,
    Motion,
    Participants,
    Session,
    Setup,
    Status,
    Telemetry,
}
Packets sent by F1 games

The modern F1 games have divided their telemetry output into multiple packets, which can be sent at different intervals based on how quickly their data changes.

Variants



Event



Lap



Motion



Participants



Session



Setup



Status



Telemetry