GameVersion

Struct GameVersion 

pub struct GameVersion { /* private fields */ }
Version number of the game

The modern F1 games include their version number in the packet header. The games are versioned using the scheme MAJOR.MINOR.

TODO Test that partial order works correctly with version numbers

Implementations

Source

impl GameVersion

pub fn new(major: u8, minor: u8) -> Self

Constructs a new GameVersion.

Source

impl GameVersion

pub fn major(&self) -> u8

Returns the major version of the game.

pub fn minor(&self) -> u8

Returns the minor version of the game.