Button

Struct Button 

pub struct Button { /* private fields */ }
A bit field with currently pressed buttons.

The F1 games publish which buttons are currently being pressed by the user. This information is encoded in a bit field, where each bit represents a different button.

Implementations

Source

impl Button

pub const NONE: Button

pub const CROSS_OR_A: Button

pub const TRIANGLE_OR_Y: Button

pub const CIRCLE_OR_B: Button

pub const SQUARE_OR_X: Button

pub const DPAD_LEFT: Button

pub const DPAD_RIGHT: Button

pub const DPAD_UP: Button

pub const DPAD_DOWN: Button

pub const OPTIONS_OR_MENU: Button

pub const L1_OR_LB: Button

pub const R1_OR_RB: Button

pub const L2_OR_LT: Button

pub const R2_OR_RT: Button

pub const LEFT_STICK_CLICK: Button

pub const RIGHT_STICK_CLICK: Button

pub const fn empty() -> Button

Returns an empty set of flags

pub const fn all() -> Button

Returns the set containing all flags.

pub const fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<Button>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> Button

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> Button

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: Button) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: Button) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: Button)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: Button)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: Button)

Toggles the specified flags in-place.

pub fn set(&mut self, other: Button, value: bool)

Inserts or removes the specified flags depending on the passed value.